# PSQF 6243 Example 4a using R

# Set width of output and  number of digits to be printed
options("width"=120, "digits"=8) 

# Use this to turn off scientific notation: 
# "fixed notation will be preferred unless it is more than 'scipen' digits wide"
options(scipen=9)

# turn off stars for different alpha levels
options(show.signif.stars=FALSE)

if (!require("readxl")) install.packages("readxl")
library(readxl) # To import excel XLSX data with labels as table

if (!require("expss")) install.packages("expss")
library(expss) # To add variable and value labels, sorting

if (!require("psych")) install.packages("psych")
library(psych) # To add descriptive summary functions

if (!require("multcomp")) install.packages("multcomp")
library(multcomp) # To do glht linear combinations in GLMs

if (!require("ppcor")) install.packages("ppcor")
library(ppcor) # To get partial and semi-partial correlations

if (!require("TeachingDemos")) install.packages("TeachingDemos")
library(TeachingDemos) # To create text output files using code below


################################################################################
#####            BEGIN EXAMPLE 4a DATA IMPORT AND MANIPULATION             #####
################################################################################

# Set working directory (to import and export files to)
# Paste in the folder address where "GSS_Example.xlsx" is saved in quotes
setwd("C:/Dropbox/22SP_PSQF6243/PSQF6243_Example4a")

# Import GSS_Example.xlsx data from working directory -- path = file name
Example4a = read_excel(path="GSS_Example.xlsx", sheet="GSS_Example") 
# Convert to data frame to use for analysis
Example4a = as.data.frame(Example4a)

### Create and label predictor variables for model 1 (same as in Example 2)
# Linear predictor for education centered so that 0 is meaningful
Example4a$educ12=Example4a$educ-12 
# educ12: Education (0=12 years)
# Recode marry predictor so that 0 is meaningful
Example4a$marry01=NA  # Create new empty variable, then recode 
Example4a$marry01[which(Example4a$marry==1)]=0 
Example4a$marry01[which(Example4a$marry==2)]=1
# marry01: 0=unmarried, 1=married 

### Create and label predictor variables for model 2 (same as in Example 3)
# 2 Indicator-dummy-coded binary predictors for workclass
Example4a$LvM=NA; Example4a$LvU=NA  # Make 2 new empty variables 
Example4a$LvM[which(Example4a$workclass==1)]=0  # Replace each for lower
Example4a$LvU[which(Example4a$workclass==1)]=0
Example4a$LvM[which(Example4a$workclass==2)]=1  # Replace each for middle
Example4a$LvU[which(Example4a$workclass==2)]=0
Example4a$LvM[which(Example4a$workclass==3)]=0  # Replace each for upper
Example4a$LvU[which(Example4a$workclass==3)]=1
# LvM: Low=0 vs Mid=1 Class
# LvU: Low=0 vs Upp=1 Class
# Center age at 18 (minimum in sample)
Example4a$age18=Example4a$age-18 
# age18: Age (0=18 years) 
# Make squared age for GLHT statements
Example4a$agesq=Example4a$age18*Example4a$age18
# agesq: Squared Age (0=18 years)
# 3 Piecewise slopes for education
# Make 3 new empty variables 
Example4a$lessHS=NA; Example4a$gradHS=NA; Example4a$overHS=NA 
# Replace each for educ less than 12
Example4a$lessHS[which(Example4a$educ<12)]=Example4a$educ[which(Example4a$educ<12)]-11  
Example4a$gradHS[which(Example4a$educ<12)]=0
Example4a$overHS[which(Example4a$educ<12)]=0  
# Replace each for educ greater or equal to 12
Example4a$lessHS[which(Example4a$educ>=12)]=0 
Example4a$gradHS[which(Example4a$educ>=12)]=1  
Example4a$overHS[which(Example4a$educ>=12)]=Example4a$educ[which(Example4a$educ>=12)]-12
# lessHS: Slope for Years Ed Less Than High School
# gradHS: Acute Bump for Graduating High School
# overHS: Slope for Years Ed After High School
# Label outcome variable
# income: Annual Income in 1000s
# Now Example4a dataset is ready to use

# Open external file to save results to
txtStart(file="Example4a_R_Output.txt")


################################################################################
#####       MODEL 1: DEMONSTRATING SINGLE-SLOPE PREDICTORS COMBINED        #####
################################################################################

print("R Predict Income from Empty Model")
ModelEmpty = lm(data=Example4a, formula=income~1)
anova(ModelEmpty)   # anova to print residual variance
summary(ModelEmpty) # summary to print fixed effects solution 
confint(ModelEmpty, level=.95) # confint for level% CI for fixed effects

# Save sums of squares from empty model for later calculations
SStotal=anova(ModelEmpty)$`Sum Sq`

txtComment(" ") # insert blank space in output  


print("R Predict Income from Linear Education Only")
ModelLinEd = lm(data=Example4a, formula=income~1+educ12)
anova(ModelLinEd)   # anova to print residual variance
summary(ModelLinEd) # summary to print fixed effects solution
confint(ModelLinEd, level=.95) # confint for level% CI for fixed effects

txtComment(" ") # insert blank space in output  

print("R Predict Income from Binary Marital Status Only")
ModelMarry = lm(data=Example4a, formula=income~1+marry01)
anova(ModelMarry)   # anova to print residual variance
summary(ModelMarry) # summary to print fixed effects solution
confint(ModelMarry, level=.95) # confint for level% CI for fixed effects

txtComment(" ") # insert blank space in output  


print("R Model 1: Predict Income from Linear Education and Binary Marital Status")
Model1 = lm(data=Example4a, formula=income~1+educ12+marry01)
anova(Model1)   # anova to print residual variance
SumModel1 = summary(Model1); SumModel1 # save summary and print fixed effects solution
confint(Model1, level=.95) # confint for level% CI for fixed effects

print("R Partial and Semi-Partial R2 of income with educ12")
 pcor.test(Example4a$income, Example4a$educ12, Example4a[,"marry01"])$estimate^2
spcor.test(Example4a$income, Example4a$educ12, Example4a[,"marry01"])$estimate^2
print("R Partial and Semi-Partial R2 of income with marry01")
 pcor.test(Example4a$income, Example4a$marry01, Example4a[,"educ12"])$estimate^2
spcor.test(Example4a$income, Example4a$marry01, Example4a[,"educ12"])$estimate^2

# Extra R code to compute effect sizes from stored model results from fixed effects
Model1pD=(2*SumModel1$coefficients[,"t value"])/sqrt(Model1$df.residual)
Model1pR=   SumModel1$coefficients[,"t value"]/
       sqrt(SumModel1$coefficients[,"t value"]^2+Model1$df.residual)
Model1sR=   SumModel1$coefficients[,"t value"]*sqrt((1-summary(Model1)$r.squared)/Model1$df.residual)
# Concatenate effect sizes to results table for fixed effects
data.frame(SumModel1$coefficients, PartialD=Model1pD, PartialR=Model1pR, SemiPartialR=Model1sR)

txtComment(" ") # insert blank space in output  



################################################################################
#####       MODEL 2: DEMONSTRATING MULTIPLE-SLOPE PREDICTORS COMBINED      #####
################################################################################

print("R Predict Income from 3-Category Workclass Only")
ModelClass = lm(data=Example4a, formula=income~1+LvM+LvU)
anova(ModelClass)   # anova to print residual variance
summary(ModelClass) # summary to print fixed effects solution 
confint(ModelClass, level=.95) # confint for level% CI for fixed effects

txtComment(" ") # insert blank space in output  

print("R Predict Income from Linear+Quadratic Age Only")
ModelAge = lm(data=Example4a, formula=income~1+age18+I(age18^2))
anova(ModelAge)   # anova to print residual variance
summary(ModelAge) # summary to print fixed effects solution
confint(ModelAge, level=.95) # confint for level% CI for fixed effects

txtComment(" ") # insert blank space in output  

print("R Predict Income from 3 Piecewise Slopes for Education Only")
ModelEd3 = lm(data=Example4a, formula=income~1+lessHS+gradHS+overHS)
anova(ModelEd3)   # anova to print residual variance
summary(ModelEd3) # summary to print fixed effects solution
confint(ModelEd3, level=.95) # confint for level% CI for fixed effects

txtComment(" ") # insert blank space in output  


print("R Model 2: Predict Income from Workclass, Quadratic Age, and Piecewise Education")
Model2 = lm(data=Example4a, formula=income~1+LvM+LvU+age18+agesq+lessHS+gradHS+overHS)
anova(Model2)   # anova to print residual variance
SumModel2 = summary(Model2); SumModel2 # save summary and print fixed effects solution
confint(Model2, level=.95) # confint for level% CI for fixed effects

print("R Ask for missing model-implied group difference")
PredModel2 = glht(model=Model2, linfct=rbind("Mid vs Upp Diff" = c(0,-1,1,0,0,0,0,0)))
print("Save glht linear combination results with unadjusted p-values and 95% CIs")
SaveModel2 = summary(PredModel2, test=adjusted("none")) 
print(SaveModel2); confint(PredModel2, level=.95, calpha=univariate_calpha())

print("Replicate F-test for model: includes all 7 slopes") 
Model2Fall = glht(model=Model2, linfct=c("LvM=0","LvU=0","age18=0","agesq=0",
                                         "lessHS=0","gradHS=0","overHS=0"))
summary(Model2Fall, test=Ftest()) # ask for joint hypothesis test instead of separate 

print("Ask for F-test for overall effect of workclass") 
Model2Fclass = glht(model=Model2, linfct=c("LvM=0","LvU=0"))
summary(Model2Fclass, test=Ftest()) # ask for joint hypothesis test instead of separate 

print("Ask for F-test for overall effect of age") 
Model2Fage = glht(model=Model2, linfct=c("age18=0","agesq=0"))
summary(Model2Fage, test=Ftest()) # ask for joint hypothesis test instead of separate 

print("Ask for F-test for overall effect of education") 
Model2Feduc = glht(model=Model2, linfct=c("lessHS=0","gradHS=0","overHS=0"))
summary(Model2Feduc, test=Ftest()) # ask for joint hypothesis test instead of separate 

print("R Semi-Partial R2 for Workclass via SS for Reduced Model Omitting Workclass")
Model2NoClass = lm(data=Example4a, formula=income~1+age18+agesq+lessHS+gradHS+overHS)
SSClass=anova(Model2NoClass, Model2); SSClass$`Sum of Sq`/SStotal

print("R Semi-Partial R2 for Age via SS for Reduced Model Omitting Age")
Model2NoAge = lm(data=Example4a, formula=income~1+LvM+LvU+lessHS+gradHS+overHS)
SSAge=anova(Model2NoAge, Model2); SSAge$`Sum of Sq`/SStotal

print("R Semi-Partial R2 for Education via SS for Reduced Model Omitting Education")
Model2NoEduc = lm(data=Example4a, formula=income~1+LvM+LvU+age18+agesq)
SSEduc=anova(Model2NoEduc, Model2); SSEduc$`Sum of Sq`/SStotal


# Extra R code to compute effect sizes from stored model results from GLHT
ClassPartialD=(2*SaveModel2$test$tstat)/sqrt(ModelClass$df.residual)
ClassPartialR=SaveModel2$test$tstat/sqrt(SaveModel2$test$tstat^2+Model2$df.residual)
ClassSemiPartialR=SaveModel2$test$tstat*sqrt((1-summary(Model2)$r.squared)/Model2$df.residual)
# Concatenate effect sizes to results table for mean differences
data.frame(Estimate=SaveModel2$test$coefficients, pvalue=SaveModel2$test$pvalues, 
           PartialD=ClassPartialD, PartialR=ClassPartialR, SemiPartialR=ClassSemiPartialR)

# Extra R code to compute effect sizes from stored model results from fixed effects
Model2pD=(2*SumModel2$coefficients[,"t value"])/sqrt(Model2$df.residual)
Model2pR=   SumModel2$coefficients[,"t value"]/
       sqrt(SumModel2$coefficients[,"t value"]^2+Model2$df.residual)
Model2sR=   SumModel2$coefficients[,"t value"]*sqrt((1-summary(Model2)$r.squared)/Model2$df.residual)
# Concatenate effect sizes to results table for fixed effects
data.frame(SumModel2$coefficients, PartialD=Model2pD, PartialR=Model2pR, SemiPartialR=Model2sR)


# Close output text file
txtStop()


