// Prevent "more" messages from appearing
set more off
// Control line length
set linesize 150

******************************************************************************
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION     *******
******************************************************************************

// Paste in the folder address where "GSS_Example.xlsx" is saved between " "
cd "C:\Dropbox\22SP_PSQF6243\PSQF6243_Example4a"
// Using UIowa virtual desktop instead
*cd "\\Client\C:\Dropbox\22SP_PSQF6243\PSQF6243_Example4a"

// IMPORT GSS_Example.xlsx data from working directory using exact file name
// To change all variable names to lowercase, remove "case(preserve")
clear // Clear before means close any open data
import excel "GSS_Example.xlsx", case(preserve) firstrow clear 
// Clear after means re-import if it already exists (if need to start over)

// Create and label predictor variables for model 1 (same as in Example 2)
// Linear predictor for educaiton centered so that 0 is meaningful
gen educ12=educ-12
label variable educ12 "educ12: Education (0=12 years)"
// Recode marry predictor so that 0 is meaningful
gen marry01=. // Create new empty variable, then recode
replace marry01=0 if marry==1
replace marry01=1 if marry==2
label variable marry01 "marry01: 0=unmarried, 1=married"

// Create and label predictor variables for model 2 (same as in Example 3)
// 2 Indicator-dummy-coded binary predictors for workclass
gen LvM=. // Make two new empty variables
gen LvU=.
replace LvM=0 if workclass==1 // Replace each for lower
replace LvU=0 if workclass==1
replace LvM=1 if workclass==2 // Replace each for middle
replace LvU=0 if workclass==2
replace LvM=0 if workclass==3 // Replace each for upper
replace LvU=1 if workclass==3
label variable LvM "LvM: Low=0 vs Mid=1 Class"
label variable LvU "LvU: Low=0 vs Upp=1 Class"
// Center age at 18 (minimum in sample)
gen age18 = age-18
label variable age18 "age18: Age (0=18 years)"
// 3 Piecewise slopes for education
gen lessHS=. // Make 3 new empty variables
gen gradHS=.
gen overHS=.
// Replace for educ less than 12
replace lessHS=educ-11 if educ <  12
replace gradHS=0       if educ <  12
replace overHS=0       if educ <  12
// Replace for educ greater or equal to 12
replace lessHS=0       if educ >= 12 
replace gradHS=1       if educ >= 12
replace overHS=educ-12 if educ >= 12
// Label variables
label variable lessHS "lessHS: Slope for Years Ed Less Than High School"
label variable gradHS "gradHS: Acute Bump for Graduating High School"
label variable overHS "overHS: Slope for Years Ed After High School"
// Label outcome
label variable income "income: Annual Income in 1000s"
// Select cases complete on variables of interest
egen nmiss = rowmiss(income educ marry workclass age)
drop if nmiss>0
// Now dataset is ready to use

// Open external file to save results to
log using Example4a_STATA_Output.log, replace 

********************************************************************************
*******    MODEL 1: DEMONSTRATING SINGLE-SLOPE PREDICTORS COMBINED       *******
********************************************************************************

display "STATA Predict Income from Empty Model"
regress income, level(95)

display "STATA Predict Income from Linear Education Only"
regress income c.educ12, level(95)

display "STATA Predict Income from Binary Marital Status Only"
regress income c.marry01, level(95)


display "STATA Model 1: Predict Income from Linear Education and Binary Marital Status"
regress income c.educ12 c.marry01, level(95)

display "STATA Semi-Partial and Partial Effect Sizes"
pcorr income educ12 marry01

display "Extra STATA code to compute effect sizes from stored results per lincom"
regress income c.educ12 c.marry01, level(95)
lincom c.educ12  // Linear Education 
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial R= " (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))
lincom c.marry01  // Binary Marital Status 
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial R= " (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))


********************************************************************************
*******    MODEL 2: DEMONSTRATING MULTIPLE-SLOPE PREDICTORS COMBINED     *******
********************************************************************************

display "STATA Predict Income from 3-Category Workclass Only"
regress income c.LvM c.LvU, level(95)

display "STATA Predict Income from Linear+Quadratic Age Only"
regress income c.age18 c.age18#c.age18, level(95) // Hashtag multiplies predictors

display "STATA Predict Income from 3 Piecewise Slopes for Education Only"
regress income c.lessHS c.gradHS c.overHS, level(95)


display "STATA Model 2: Predict Income from Workclass, Quadratic Age, and Piecwise Education"
regress income c.LvM c.LvU c.age18 c.age18#c.age18 c.lessHS c.gradHS c.overHS, level(95)
// Ask for missing model-implied group difference
lincom c.LvM*-1 + c.LvU*1 // Mid v Upp Diff 
// Replicate F-test for the model: includes all 7 slopes
test (c.LvM=0)(c.LvU=0)(c.age18=0)(c.age18#c.age18=0)(c.lessHS=0)(c.gradHS=0)(c.overHS=0) 
// Ask for F-test for overall effect of workclass
test (c.LvM=0)(c.LvU=0)
// Ask for F-test for overall effect of age       
test (c.age18=0)(c.age18#c.age18=0)  
// Ask for F-test for overall effect of education
test (c.lessHS=0)(c.gradHS=0)(c.overHS=0) 

display "STATA Reduced Model to Get Model SS from Omitting Workclass"
regress income c.age18 c.age18#c.age18 c.lessHS c.gradHS c.overHS, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (40246.42433-34284.6688)/139423.2319 // sr2 for workclass

display "STATA Reduced Model to Get Model SS from Omitting Age"
regress income c.LvM c.LvU c.lessHS c.gradHS c.overHS, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (40246.42433-29022.8166)/139423.2319 // sr2 for age

display "STATA Reduced Model to Get Model SS from Omitting Education"
regress income c.LvM c.LvU c.age18 c.age18#c.age18, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (40246.42433-28994.6361)/139423.2319 // sr2 for education


display "Extra STATA code to compute effect sizes from stored results per lincom"
regress income c.LvM c.LvU c.age18 c.age18#c.age18 c.lessHS c.gradHS c.overHS, level(95)
lincom c.LvM*-1 + c.LvU*1 // Mid vs Upp WorkClass   
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial R= " (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))
lincom c.LvM // Low vs Mid WorkClass   
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial R= " (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))
lincom c.LvU // Low vs Upp WorkClass   
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial R= " (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))
lincom c.age18 // Linear Age conditional at 18  
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial R= " (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))
lincom c.age18#c.age18 // Quadratic Age
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial R= " (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))
lincom c.lessHS // Education 2-11 years
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial R= " (r(estimate)/r(se))*sqrt((1-e(r2))/r(df)) 
lincom c.gradHS // Education 11-12 years
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial R= " (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))    
lincom c.overHS // Education 12-20 years
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
   display "Semi-Partial R= " (r(estimate)/r(se))*sqrt((1-e(r2))/r(df))    
   

// Close external file of saved results
log close  

   
   



